terminusgps-notifications documentation
=======================================

============
Introduction
============

`Terminus GPS Notifications <https://api.terminusgps.com/>`_ is an online platform that enables `Wialon`_ users to deliver messages to end-user phone numbers using Wialon `notifications <https://help.wialon.com/en/wialon-hosting/user-guide/quick-start/notifications>`_.

:doc:`Wialon notifications created and managed <guides/creating_a_live_notification>` in the *Terminus GPS Notifications* platform deliver your custom message (via SMS or text-to-speech) to :doc:`phone numbers you configure <guides/setting_destination_phone_numbers>`.

=============
Core features
=============

- **Fully customizable live notifications**: Configure either sms text messages or text-to-speech voice messages to deliver to your end-users.

- **Simplified payment management**: Subscribe to the service for 500 messages per month or purchase additional message packages to match your usage.

- **Comprehensive dashboard**: Get a quick-and-dirty overview of your current usage and your account's status.

- **Dedicated in-house support**: Drop us a line at any time for questions or concerns regarding your account, billing issues or technical setup.

===============
Getting started
===============

------------
Requirements
------------

You'll need to have everything listed below ready to go **before** you create your account:

* A `Wialon`_ account.
* A valid credit card and shipping address.

------------
Step-by-step
------------

To get started delivering messages to end-user phone numbers as fast as possible:

#. :doc:`Create an account <guides/creating_an_account>` on the *Terminus GPS Notifications* website.

#. Add a credit card and shipping address to `your account <https://api.terminusgps.com/account/>`_.

#. :doc:`Subscribe <guides/subscribing>` to the *Terminus GPS Notifications* platform.

#. :doc:`Connect your Wialon account <guides/connecting_your_wialon_account>`.

#. :doc:`Configure destination phone numbers <guides/setting_destination_phone_numbers>`.

#. :doc:`Create a live notification <guides/creating_a_live_notification>`.

.. _Wialon: https://help.wialon.com/en/wialon-platform

.. toctree::
    :maxdepth: 2
    :caption: Contents:
    
    guides/index.rst
    models.rst

